data "archive_file" "index_deployer" {
  type        = "zip"
  output_path = "${path.module}/dist/index_deployer_lambda.zip"

  source {
    filename = "index.js"
    content  = "${file("${path.module}/index_deployer_lambda.js")}"
  }
}

resource "aws_lambda_function" "index_deployer" {
  function_name = "${var.app_name}-index_deployer"

  filename         = "${data.archive_file.index_deployer.output_path}"
  source_code_hash = "${data.archive_file.index_deployer.output_base64sha256}"
  role             = "${aws_iam_role.index_deployer.arn}"
  runtime          = "nodejs6.10"
  handler          = "index.handler"
  memory_size      = 128
  timeout          = 10
  publish          = false
}

resource "aws_iam_role" "index_deployer" {
  name = "${var.app_name}-index_deployer-role"

  assume_role_policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Effect": "Allow",
      "Principal": {
        "Service": [
          "lambda.amazonaws.com"
        ]
      },
      "Action": "sts:AssumeRole"
    }
  ]
}
EOF
}

resource "aws_iam_policy" "index_deployer" {
  name = "${var.app_name}-index_deployer-policy"

  policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Action": [
        "logs:CreateLogGroup",
        "logs:CreateLogStream",
        "logs:PutLogEvents"
      ],
      "Effect": "Allow",
      "Resource": "arn:aws:logs:*:*:*"
    }
  ]
}
EOF
}

resource "aws_iam_role_policy_attachment" "index_deployer" {
  role       = "${aws_iam_role.index_deployer.name}"
  policy_arn = "${aws_iam_policy.index_deployer.arn}"
}
