resource "aws_lambda_permission" "index_deployer_access" {
  statement_id  = "${var.resource_prefix}-AllowExecutionFromS3"
  action        = "lambda:InvokeFunction"
  function_name = "${var.index_deployer_lambda_name}"
  principal     = "s3.amazonaws.com"
  source_arn    = "${aws_s3_bucket.website.arn}"
}

resource "aws_s3_bucket_notification" "index_deployer_notification" {
  bucket = "${aws_s3_bucket.website.id}"

  lambda_function {
    lambda_function_arn = "${var.index_deployer_lambda_arn}"
    events              = ["s3:ObjectCreated:*"]
    filter_suffix       = "/index.html"
  }
}

resource "aws_iam_policy" "index_deployer" {
  name = "${var.resource_prefix}-index_deployer-policy"

  policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Action": [
        "s3:GetObject",
        "s3:PutObject"
      ],
      "Effect": "Allow",
      "Resource": "${aws_s3_bucket.website.arn}/*"
    }
  ]
}
EOF
}

resource "aws_iam_role_policy_attachment" "index_deployer" {
  role       = "${var.index_deployer_lambda_role_name}"
  policy_arn = "${aws_iam_policy.index_deployer.arn}"
}
